/**
 * Model-based Level Set (MLS) Algorithm
 *
 * COPYRIGHT NOTICE
 * Copyright (c) 2003-2005 Audrey H. Zhuang and Daniel J. Valentino
 *
 * Please read LICENSE.TXT for the license covering this software
 *
 * For more information, please contact the authors at:
 * haihongz@seas.ucla.edu
 * dvalentino@mednet.ucla.edu
 */
package mlsSkullStrip;

import java.io.File;


/**
 * Application to skull-strip an MR brain volume. 
 *
 * @author Audrey H. Zhuang and Daniel J. Valentino
 * @version 2 September 2005
 */
public class MLS_SkullStrip
{
    /** DataManager object for viewing and displaying images. */
    private DataManager _dataManager;
    private CommandLineParser _parser = null;

  /**
   * Constructs LONI_Anatomist.  Creates the tree and viewport for image 
   * display. 
   */
  public MLS_SkullStrip(String fileNames[])
  {
    // Parse user command line
    if(fileNames.length > 0) _parser = new CommandLineParser(fileNames);
    _dataManager = new DataManager();
    if(_parser.getInputFile() == null){
	_usage();
	System.exit(0);
    }
    System.out.print("Loading data... ");
    loadFile(_parser.getInputFile());
    doSkullStripping();
    if(_parser.isFillingHolesEnabled()) fillHoles();
    if(_parser.getOutputMaskFile() != null) 
	saveMaskFile(_parser.getOutputMaskFile().toString() );
    if(_parser.getOutputBrainOnlyFile() != null)
	saveBrainOnlyFile(_parser.getOutputBrainOnlyFile().toString() );
    System.exit(0);
  }

  /**
   * Main method of LONI_Anatomist displays splash screen and displays itself.
   */
  public static void main( String args[] )
  {  
    new MLS_SkullStrip(args);
  }

  /**
   * Starts the skull stripping.
   */
  public void doSkullStripping()
  {
      _dataManager.doSkullStripping();
  }

  /**
   * Fill the holes in the brain mask.
   */
  public void fillHoles()
  {
    _dataManager.fillHoles();
  }

  /**
   * Load a file to skull-strip.
   */
  public void loadFile(File file)
  {
      try{
	  _dataManager.loadFile(file, _parser);
      }catch(Exception e){
	  e.printStackTrace();
      }
  }

  public void saveBrainOnlyFile(String fileName)
  {
      _dataManager.saveBrainOnlyFile(fileName);
  }

  /**
   * Save skull-stripped images.
   */
  public void saveMaskFile(String fileName)
  {
      _dataManager.saveMaskFile(fileName);
  }

  private static void _usage()
  {
    System.out.println("Usage: <memory allocation> -jar Segmentation.jar -i file -m file -b file <options> ");
    System.out.println("Options: Description:");
    System.out.println("-i       <file>");    
    System.out.println("         an image file to skull strip");
    System.out.println("-m       <file>");     
    System.out.println("         a brain mask file to save");
    System.out.println("-b       <file>");
    System.out.println("         a brain only mask file to save");
//     System.out.println("-m       <int value>");
//     System.out.println("         model type: 1 for normal young brains;");
//     System.out.println("         2 for aging or Alzheimer's brains;");
    System.out.println("-v       <value>");
    System.out.println("         weight on contours' constrain");
    System.out.println("-p       <value>");
    System.out.println("         heading direction: 0-north, 1-east, 2-south, 3-west");
    System.out.println("-t       <value between 0 and 1, default is 0.5>");
    System.out.println("         threshold determinter");
//     System.out.println("-f       fill holes generated in brain mask");
  }
}
